aboutsummaryrefslogtreecommitdiffstats
path: root/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h26
1 files changed, 18 insertions, 8 deletions
diff --git a/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h b/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
index aa6f4ce..ef53fea 100644
--- a/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
+++ b/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
@@ -128,19 +128,29 @@ void rtgrpblib_draw_cubic_bezier(RTGRPBLIB_RASTER *restrict raster,
double x4, double y4);
/**
* Draw a elliptical arc
*
* @param raster The drawing buffer
- * @param x0, y0 The midpoint of the ellipse
- * @param semiwidth Half the width of the ellipse
- * @param semiheight Half the height of the ellipse
+ * @param x0, y0 The midpoint of the circle
+ * @param semiwidth Half the width of the circle
+ * @param semiheight Half the height of the circle
* @param start The angular starting point of the arc, in radians
* @param end The angular end point of the arc, in radians
+ *
+ * Rather than specify a radius, a semimajor and semiminor is
+ * specified, despite this, the shape is called a circular rather
+ * than elliptical, this is because the function is indented to
+ * draw a circular arc on a image with different horizontal
+ * and vertical cell densities; note an elliptical arc on an image
+ * with the same horizontal as vertical cell density. This is
+ * why the function doesn't provide a way to rotate the ellipse:
+ * it's a circle, not an ellipse, and circles are perfectly
+ * symmetrical
*/
-void rtgrpblib_draw_elliptical_arc(RTGRPBLIB_RASTER *restrict raster,
- double x0, double y0,
- double semiwidth, double semiheight,
- double start, double end);
+void rtgrpblib_draw_circular_arc(RTGRPBLIB_RASTER *restrict raster,
+ double x0, double y0,
+ double semiwidth, double semiheight,
+ double start, double end);
#if defined(__clang__)
@@ -128,19 +128,29 @@ void rtgrpblib_draw_cubic_bezier(RTGRPBLIB_RASTER *restrict raster,
double x4, double y4);
/**
- * Draw a elliptical arc
+ * Draw a circular arc
*
* @param raster The drawing buffer